@@ -423,7 +423,7 @@ void TopLevel::createMiscActions()
     action->setIcon( QIcon::fromTheme(QStringLiteral("view-refresh")) );
     action->setText( i18nc("Reload a document", "&Reload" ) );
     connect(action, &QAction::triggered, this, &TopLevel::reload);
-    actionCollection()->setDefaultShortcut(action, KStandardShortcut::Reload);
+    actionCollection()->setDefaultShortcuts(action, KStandardShortcut::reload());
     hint = i18n("<b>Reload Profile Data</b>"
                 "<p>This loads any new created parts, too.</p>");
     action->setWhatsThis( hint );
@@ -2020,8 +2020,8 @@ void TopLevel::forceTrace()
     _ccProcess = new QProcess(this);
     connect(_ccProcess, &QProcess::readyReadStandardOutput,
             this, &TopLevel::ccReadOutput);
-    connect(_ccProcess, SIGNAL(error(QProcess::ProcessError)),
-            SLOT(ccError(QProcess::ProcessError)));
+    connect(_ccProcess, &QProcess::errorOccurred,
+            this, &TopLevel::ccError);
     connect(_ccProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
             SLOT(ccExit(int,QProcess::ExitStatus)));
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
